#! /bin/ksh
# @(#)get_splus_exec 1.1
#
# Script for determining the name of the S-plus command interpreter.
#

typeset script_name_without_path="${0##*/}"
typeset -r script_name="${script_name_without_path%.*}"
typeset -r path_gchome=${GCHOME:=./}
typeset path_shome=$SHOME
typeset exec_splus

if [ ${#SHOME} -eq 0 ] ;
then
    print -u2 "Environment variable 'SHOME' must be set to run this"
    print -u2 "script. It must point to the S-plus root directory."
    exit 2
else
    if [ ! -d $SHOME ] ;
    then
        print -u2 "Directory specified by environment variable 'SHOME'"
        print -u2 "<" $SHOME "> does not exist."
        exit 2
    fi

    # Look for versioned name (Splus5 or Splus6)
    typeset basename=$( basename $SHOME )
    typeset -u -L1 first_letter=$basename

    typeset name_with_version=$first_letter${basename#?}
    path_splus=$( whence -p $name_with_version )

    if [ ${#path_splus} -eq 0 ] ;
    then
        # Look for unversioned name (Splus)
        typeset name_without_version=${name_with_version%?}
        path_splus=$( whence -p $name_without_version )

        if [ ${#path_splus} -eq 0 ] ;
        then
            print -u2 "Cannot find executable named either <"
            print -u2 $name_with_version "> or <" $name_without_version ">."
            exit 2
        else
            exec_splus=$name_without_version
        fi
    else
        exec_splus=$name_with_version
    fi

    if [ ! -x "$path_splus" ] ;
    then
        print -u2 "Detected S-plus command interpreter <" $exec_splus ">"
        print -u2 "is not executable."
        exit 2
    fi
fi

print $exec_splus
exit $?

